Module prelude

Module prelude 

essential traits and re-exports

Re-exports

pub use crate::Entrypoint;
pub use crate::DotEnvParser;
pub use crate::DotEnvParserConfig;
pub use crate::Logger;
pub use crate::LoggerConfig;
pub use crate::anyhow;
pub use crate::clap;
pub use crate::tracing;
pub use crate::tracing_subscriber;
pub use crate::macros::*;

Modules

event
Events represent single points in time during the execution of a program.
instrument
Attach a span to a std::future::Future.
reload
Wrapper for a Layer to allow it to be dynamically reloaded.
span
Spans represent periods of time in which a program was executing in a particular context.

Macros

debug
Constructs an event at the debug level.
debug_span
Constructs a span at the debug level.
enabled
Checks whether a span or event is enabled based on the provided metadata.
error
Constructs an event at the error level.
error_span
Constructs a span at the error level.
event
Constructs a new Event.
info
Constructs an event at the info level.
info_span
Constructs a span at the info level.
span
Constructs a new span.
trace
Constructs an event at the trace level.
trace_span
Constructs a span at the trace level.
warn
Constructs an event at the warn level.
warn_span
Constructs a span at the warn level.

Structs

Compact
Marker for Format that indicates that the compact log format should be used.
Format
A pre-configured event formatter.
Full
Marker for Format that indicates that the default log format should be used.
Json
Marker for Format that indicates that the newline-delimited JSON log format should be used.
Layer
A Layer that logs formatted representations of tracing events.
Level
Describes the level of verbosity of a span or event.
LevelFilter
A filter comparable to a verbosity Level.
Pretty
An excessively pretty, human-readable event formatter.
Registry
A shared, reusable store for spans.

Traits

Context
Provides the context method for Result.
FormatEvent
A type that can format a tracing Event to a Writer.
FormatFields
A type that can format a set of fields to a Writer.
LookupSpan
Provides access to stored span data.
MakeWriter
A type that can create io::Write instances.
Parser
Parse command-line arguments into Self.
Subscriber
Trait representing the functions required to collect trace data.
_
Extension trait adding utility methods for subscriber initialization.
__tracing_subscriber_Layer
A composable handler for tracing events.
__tracing_subscriber_SubscriberExt
Extension trait adding a with(Layer) combinator to Subscribers.
__tracing_subscriber_field_MakeExt
Extension trait providing MakeVisitor combinators.
__tracing_subscriber_field_RecordFields
Extension trait implemented by types which can be recorded by a visitor.

Attribute Macros

instrument
Instruments a function to create and enter a tracing span every time the function is called.

Derive Macros

Parser
Generates the Parser implementation.